@@ -240,12 +240,13 @@ class Server():
 
     def read_json(self, file_path: str) -> Optional[Any]:
         log.info(f"正在读取JSON文件 - {file_path}")
+        json_data=dict({})
         if not os.path.exists(file_path):
             log.warning(f"读取JSON文件 - {file_path},错误: 文件不存在 - {file_path}")
-            return None
+            return json_data
         if not os.path.isfile(file_path):
             log.warning(f"读取JSON文件 - {file_path},错误: 不是有效的文件 - {file_path}")
-            return None
+            return json_data
         try:
             with open(file_path, 'r', encoding='utf-8') as file:
                 try:
@@ -254,16 +255,16 @@ class Server():
                     return json_data
                 except json.JSONDecodeError as e:
                     log.warning(f"读取JSON文件 - {file_path},错误: JSON解析失败 - {str(e)}，文件: {file_path}")
-                    return None
+                    return json_data
                 except Exception as e:
                     log.warning(f"读取JSON文件 - {file_path},错误: 读取文件内容时发生意外 - {str(e)}，文件: {file_path}")
-                    return None
+                    return json_data
         except PermissionError:
             log.warning(f"读取JSON文件 - {file_path},错误: 没有权限打开文件 - {file_path}")
-            return None
+            return json_data
         except Exception as e:
             log.warning(f"读取JSON文件 - {file_path},错误: 打开文件时发生意外 - {str(e)}，文件: {file_path}")
-            return None
+            return json_data
 
     def get_abs_path(self, file_name: str, dest_dir: str) -> Optional[str]:
         log.info(f"正在获取绝对路径 - 文件名: {file_name}，目标目录: {dest_dir}")
